==> truffle-api-20.0.0-sources.jar: com/oracle/truffle/api/instrumentation/ThreadsListener.java <==
/*
 * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.api.instrumentation;

import com.oracle.truffle.api.TruffleContext;

/**
 * Listener to be notified about changes of threads in guest language application.
 * <p>
 * Use
 * {@link Instrumenter#attachThreadsListener(com.oracle.truffle.api.instrumentation.ThreadsListener, boolean)}
 * to register an implementation of this listener. Use {@link EventBinding#dispose()} to unregister.
 * <p>
 * The listener gets called when a thread is initialized for use in a {@link TruffleContext context}
 * or thread-related resources are disposed in a context. The notification calls do not say anything
 * about the actual life-time of the thread as such, which may live before the initialization and
 * may continue to live after the disposal.
 *
 * @see Instrumenter#attachThreadsListener(com.oracle.truffle.api.instrumentation.ThreadsListener,
 *      boolean)
 * @since 0.30
 */
public interface ThreadsListener {

    /**
     * Notifies about initialization of a thread to be used for a guest language execution in a
     * {@link TruffleContext}.
     *
     * @param context the context the thread is initialized in
     * @param thread the initialized thread
     * @since 0.30
     */
    void onThreadInitialized(TruffleContext context, Thread thread);

    /**
     * Notifies about disposal of thread-related resources that were used for a guest language
     * execution in a {@link TruffleContext}.
     *
     * @param context the context the thread is disposed from
     * @param thread the thread
     * @since 0.30
     */
    void onThreadDisposed(TruffleContext context, Thread thread);
}

==> truffle-api-21.1.0-sources.jar: com/oracle/truffle/api/instrumentation/ThreadsListener.java <==
/*
 * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.api.instrumentation;

import com.oracle.truffle.api.TruffleContext;

/**
 * Listener to be notified about changes of threads in guest language application.
 * <p>
 * Use
 * {@link Instrumenter#attachThreadsListener(com.oracle.truffle.api.instrumentation.ThreadsListener, boolean)}
 * to register an implementation of this listener. Use {@link EventBinding#dispose()} to unregister.
 * <p>
 * The listener gets called when a thread is initialized for use in a {@link TruffleContext context}
 * or thread-related resources are disposed in a context. The notification calls do not say anything
 * about the actual life-time of the thread as such, which may live before the initialization and
 * may continue to live after the disposal.
 *
 * @see Instrumenter#attachThreadsListener(com.oracle.truffle.api.instrumentation.ThreadsListener,
 *      boolean)
 * @since 0.30
 */
public interface ThreadsListener {

    /**
     * Notifies about initialization of a thread to be used for a guest language execution in a
     * {@link TruffleContext}. If this method throws an
     * {@link com.oracle.truffle.api.exception.AbstractTruffleException} the exception interop
     * messages may be executed without a context being entered.
     *
     * @param context the context the thread is initialized in
     * @param thread the initialized thread
     * @since 0.30
     */
    void onThreadInitialized(TruffleContext context, Thread thread);

    /**
     * Notifies about disposal of thread-related resources that were used for a guest language
     * execution in a {@link TruffleContext}.
     *
     * @param context the context the thread is disposed from
     * @param thread the thread
     * @since 0.30
     */
    void onThreadDisposed(TruffleContext context, Thread thread);
}
